/*
 * @Author: Kane
 * @Date: 2023-10-11 16:47:59
 * @LastEditors: Kane
 * @FilePath: /desktop_archievement_backend/src/main/java/com/cpic/xim/mybatis/mapper/ImportBIArchievementDataMapper.java
 * @Description: 
 * 
 * Copyright (c) ${2023} by Kane, All Rights Reserved. 
 */
package com.cpic.xim.mybatis.mapper;

import com.cpic.xim.mybatis.pojo.BIDepartmentAttachingRateRecord;
import com.cpic.xim.mybatis.pojo.BIDepartmentRenewalRateRecord;
import com.cpic.xim.mybatis.pojo.BITelsalerAttachingRateRecord;
import com.cpic.xim.mybatis.pojo.BITelsalerRenewalRateRecord;

public interface ImportBIArchievementDataMapper
{
    public void insertTelsalerAttachingRateDataToDB( BITelsalerAttachingRateRecord record);

    public void insertTelsalerRenewalRateDataToDB( BITelsalerRenewalRateRecord record );

    public void insertDepartmentAttachingRateDataToDB(BIDepartmentAttachingRateRecord record);

    public void insertDepartmentRenewalRateDataToDB(BIDepartmentRenewalRateRecord record);
   
    public void cleanTelsalerAttachingRateData();

    public void cleanTelsalerRenewalRateData();

    public void cleanDepartmentAttachingRateData();

    public void cleanDepartmentRenewalRateData();
}